[java-identity-provider COMMIT] in /trunk: idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractPr...
noreply at shibboleth.net
noreply at shibboleth.net
Sat Apr 19 19:19:29 EDT 2014
Author: scantor
Date: Sat Apr 19 19:19:29 2014
New Revision: 5749
URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5749&view=rev
Log:
Check-point rest of profile config changes.
Modified:
trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractProfileConfiguration.java
trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/ProfileConfiguration.java
trunk/idp-profile-impl/src/main/java/net/shibboleth/idp/profile/config/navigate/InboundMessageHandlerLookupFunction.java
trunk/idp-profile-impl/src/main/java/net/shibboleth/idp/profile/config/navigate/OutboundMessageHandlerLookupFunction.java
Modified: trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractProfileConfiguration.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractProfileConfiguration.java?rev=5749&r1=5748&r2=5749&view=diff
==============================================================================
--- trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractProfileConfiguration.java (original)
+++ trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/AbstractProfileConfiguration.java Sat Apr 19 19:19:29 2014
@@ -24,21 +24,19 @@
import net.shibboleth.utilities.java.support.logic.Constraint;
import net.shibboleth.utilities.java.support.primitive.StringSupport;
-import org.opensaml.messaging.handler.MessageHandler;
-
import com.google.common.base.Objects;
/** Base class for {@link ProfileConfiguration} implementations. */
public abstract class AbstractProfileConfiguration implements ProfileConfiguration {
/** ID of the profile configured. */
- @Nonnull @NotEmpty private final String id;
+ @Nonnull @NotEmpty private final String profileId;
- /** Inbound message handler. */
- @Nullable private MessageHandler inboundHandler;
+ /** Inbound flow ID. */
+ @Nullable private String inboundFlowId;
- /** Outbound message handler. */
- @Nullable private MessageHandler outboundHandler;
+ /** Outbound flow ID. */
+ @Nullable private String outboundFlowId;
/** The security configuration for this profile. */
@Nullable private SecurityConfiguration securityConfiguration;
@@ -46,16 +44,16 @@
/**
* Constructor.
*
- * @param profileId ID of the the communication profile, never null or empty
+ * @param id ID of the the communication profile, never null or empty
*/
- public AbstractProfileConfiguration(@Nonnull @NotEmpty final String profileId) {
- id = Constraint.isNotNull(StringSupport.trimOrNull(profileId), "Profile identifier cannot be null or empty");
+ public AbstractProfileConfiguration(@Nonnull @NotEmpty final String id) {
+ profileId = Constraint.isNotNull(StringSupport.trimOrNull(id), "Profile identifier cannot be null or empty");
}
/** {@inheritDoc} */
@Override
@Nonnull @NotEmpty public String getId() {
- return id;
+ return profileId;
}
/** {@inheritDoc} */
@@ -75,38 +73,38 @@
/** {@inheritDoc} */
@Override
- @Nullable public MessageHandler getInboundMessageHandler() {
- return inboundHandler;
+ @Nullable public String getInboundSubflowId() {
+ return inboundFlowId;
}
/**
- * Set the inbound message handler to run.
+ * Set the subflow ID to execute prior to mainline profile processing.
*
- * @param handler inbound message handler
+ * @param id subflow ID
*/
- public void setInboundHandler(@Nullable final MessageHandler handler) {
- inboundHandler = handler;
+ public void setInboundSubflowId(@Nullable final String id) {
+ inboundFlowId = StringSupport.trimOrNull(id);
}
/** {@inheritDoc} */
@Override
- @Nullable public MessageHandler getOutboundMessageHandler() {
- return outboundHandler;
+ @Nullable public String getOutboundSubflowId() {
+ return outboundFlowId;
}
/**
- * Set the outbound message handler to run.
+ * Set the subflow ID to execute after mainline profile processing.
*
- * @param handler outbound message handler
+ * @param id subflow ID
*/
- public void setOutboundHandler(@Nullable final MessageHandler handler) {
- outboundHandler = handler;
+ public void setOutboundSubflowId(@Nullable final String id) {
+ outboundFlowId = StringSupport.trimOrNull(id);
}
/** {@inheritDoc} */
@Override
public int hashCode() {
- return id.hashCode();
+ return profileId.hashCode();
}
/** {@inheritDoc} */
@@ -125,7 +123,7 @@
}
AbstractProfileConfiguration other = (AbstractProfileConfiguration) obj;
- return Objects.equal(id, other.getId());
+ return Objects.equal(profileId, other.getId());
}
}
Modified: trunk/idp-profile-api/src/main/java/net/shibboleth/idp/profile/config/ProfileConfiguration.java
[... 42 lines stripped ...]
More information about the commits
mailing list